BonfireGameInterface class abstract

Created by

─▄▀─▄▀ ──▀──▀ █▀▀▀▀▀█▄ █░░░░░█─█ ▀▄▄▄▄▄▀▀

Rafaelbarbosatec on 19/11/21

Implementers

Constructors

BonfireGameInterface()

Properties

camera → Camera
no setter
children → ComponentSet
no setter
collisionAreaColor → Color?
no setter
colorFilter → ColorFilterInterface?
no setter
constructionModeColor → Color?
no setter
context → BuildContext
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasLayout → bool
no setter
highestPriority → int
no setter
interface → GameInterface?
no setter
joystick → JoystickController?
no setter
lighting → LightingInterface?
no setter
map → MapGame
no setter
overlays → ActiveOverlaysNotifier
A property that stores an ActiveOverlaysNotifier
no setter
player → Player?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showCollisionArea → bool
no setter
showFPS → bool
no setter
size → Vector2
no setter

Methods

add(Component component) → Future<void>?
Used to add component in the game.
addAll(List<Component> components) → Future<void>
Used to add component list in the game.
addJoystickObserver(GameComponent target, {bool cleanObservers = false, bool moveCameraToTarget = false}) → void
Used to change Joystick listener. And move camera to new target.
addParticle(Particle particle, {Vector2? position, Vector2? size, Vector2? scale, double? angle, Anchor? anchor, int? priority = LayerPriority.MAP + 1}) → void
Used to add particles in game.
attackables() → Iterable<Attackable>
Used to get all "Attackables".
collisions() → Iterable<ObjectCollision>
Used to get all collisions.
componentsByType<T>() → Iterable<T>
Used to find component by type.
decorations() → Iterable<GameDecoration>
Used to get all "Decoration".
enemies() → Iterable<Enemy>
Used to get all "Enemies".
getValueGenerator(Duration duration, {double begin = 0.0, double end = 1.0, Curve curve = Curves.decelerate, VoidCallback? onFinish, ValueChanged<double>? onChange}) → ValueGeneratorComponent
Used to generate numbers to create your animations.
isVisibleInCamera(GameComponent c) → bool
Used to check if a component is visible in the camera.
livingEnemies() → Iterable<Enemy>
Used to get living "Enemies".
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseEngine() → void
Used to pause the engine.
resumeEngine() → void
Used to resume the engine.
screenToWorld(Vector2 position) → Vector2
This method convert screen position to word position
toString() → String
A string representation of this object.
inherited
visibleAttackables() → Iterable<Attackable>
Used to get visible "Attackables".
visibleCollisions() → Iterable<ObjectCollision>
Used to get visible collisions.
visibleComponents() → Iterable<GameComponent>
Used to get visible "Components".
visibleComponentsByType<T>() → Iterable<T>
Used to find visible component by type.
visibleDecorations() → Iterable<GameDecoration>
Used to get visible "Decoration".
visibleEnemies() → Iterable<Enemy>
Used to get visible "Enemies".
visibleLighting() → Iterable<Lighting>
Used to get visible "Lighting".
visibleSensors() → Iterable<Sensor>
Used to get visible "Sensors".
worldToScreen(Vector2 position) → Vector2
This method convert word position to screen position

Operators

operator ==(Object other) → bool
The equality operator.
inherited