PositionType enum

Used to define which coordinate system a given top-level component respects.

Normally components live in the "game" coordinate system, which just means they respect both the camera and viewport.

Inheritance
Available extensions

Values

game → const PositionType

Default type. Respects camera and viewport (applied on top of widget).

viewport → const PositionType

Respects viewport only (ignores camera) (applied on top of widget).

widget → const PositionType

Position in relation to the coordinate system of the Flutter game widget (i.e. the raw canvas).

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<PositionType>
A constant List of the values in this enum, in order of their declaration.