Say class

Constructors

Say({required List<TextSpan> text, PersonSayDirection personSayDirection = PersonSayDirection.LEFT, BoxDecoration? boxDecoration, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, Widget? person, Widget? background, Widget? header, Widget? bottom, int? speed})
Create a text animation to be shown inside TalkDialog.show

Properties

background → Widget?
final
bottom → Widget?
final
boxDecoration → BoxDecoration?
final
hashCode → int
The hash code for this object.
no setterinherited
final
margin → EdgeInsetsGeometry?
final
padding → EdgeInsetsGeometry?
final
person → Widget?
final
personSayDirection → PersonSayDirection
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speed → int?
How long each character takes to be shown, in milliseconds. Defaults to 50.
final
text → List<TextSpan>
List of TextSpans to be shown in a TalkDialog. Example:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited